Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/mono.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMartin Baulig <martin@novell.com>2003-12-06 23:12:35 +0300
committerMartin Baulig <martin@novell.com>2003-12-06 23:12:35 +0300
commit401b59834247d06c9c4950459c1f00e965fe35e4 (patch)
tree0d928b68f0430caf7cf747faea4941157fd66b8d /mcs/class/System/System.Diagnostics
parent0f56c00bb002920fcdf428bfc4d0f221dae29405 (diff)
2003-12-06 Martin Baulig <martin@ximian.com>
* DefaultTraceListener: Don't use `where' in variable names. svn path=/trunk/mcs/; revision=20823
Diffstat (limited to 'mcs/class/System/System.Diagnostics')
-rw-r--r--mcs/class/System/System.Diagnostics/ChangeLog6
-rw-r--r--mcs/class/System/System.Diagnostics/DefaultTraceListener.cs26
2 files changed, 18 insertions, 14 deletions
diff --git a/mcs/class/System/System.Diagnostics/ChangeLog b/mcs/class/System/System.Diagnostics/ChangeLog
index 77f86bd298b..d15463fad66 100644
--- a/mcs/class/System/System.Diagnostics/ChangeLog
+++ b/mcs/class/System/System.Diagnostics/ChangeLog
@@ -1,3 +1,7 @@
+2003-12-06 Martin Baulig <martin@ximian.com>
+
+ * DefaultTraceListener: Don't use `where' in variable names.
+
2003-11-13 Andreas Nahr <ClassDevelopment@A-SoftTech.com>
* ICollectData.cs: Fixed signature
@@ -346,4 +350,4 @@
2001-09-09 Nick Drochak <ndrochak@gol.com>
* ChangeLog: added this file
- * Switch.cs: call OnSwitchSettingChanged() when the switch setting is, yes you gessed it, changed. \ No newline at end of file
+ * Switch.cs: call OnSwitchSettingChanged() when the switch setting is, yes you gessed it, changed.
diff --git a/mcs/class/System/System.Diagnostics/DefaultTraceListener.cs b/mcs/class/System/System.Diagnostics/DefaultTraceListener.cs
index 4201a82d04d..0242b19132c 100644
--- a/mcs/class/System/System.Diagnostics/DefaultTraceListener.cs
+++ b/mcs/class/System/System.Diagnostics/DefaultTraceListener.cs
@@ -44,22 +44,22 @@ namespace System.Diagnostics {
// If we're running on Unix, we don't have OutputDebugString.
// Instead, send output to...wherever the MONO_TRACE environment
// variables says to.
- String where = Environment.GetEnvironmentVariable("MONO_TRACE");
+ String trace = Environment.GetEnvironmentVariable("MONO_TRACE");
- if (where != null) {
+ if (trace != null) {
string file = null;
string prefix = null;
- if (where.StartsWith (ConsoleOutTrace)) {
+ if (trace.StartsWith (ConsoleOutTrace)) {
file = ConsoleOutTrace;
- prefix = GetPrefix (where, ConsoleOutTrace);
+ prefix = GetPrefix (trace, ConsoleOutTrace);
}
- else if (where.StartsWith (ConsoleErrorTrace)) {
+ else if (trace.StartsWith (ConsoleErrorTrace)) {
file = ConsoleErrorTrace;
- prefix = GetPrefix (where, ConsoleErrorTrace);
+ prefix = GetPrefix (trace, ConsoleErrorTrace);
}
else {
- file = where;
+ file = trace;
// We can't firgure out what the prefix would be, as ':' is a
// valid filename character. Thus, arbitrary files don't support
@@ -91,16 +91,16 @@ namespace System.Diagnostics {
* prefix.
*
* @param var The current MONO_TRACE variable
* @param where The name of the output location, e.g. "Console.Out"
*/
- private static string GetPrefix (string var, string where)
+ private static string GetPrefix (string var, string target)
{
// actually, we permit any character to separate `where' and the prefix;
// we just skip over where the ':' would be. This means that a space or
// anything else would suffice, as long as it was only a single
// character.
- if (var.Length > where.Length)
- return var.Substring (where.Length + 1);
+ if (var.Length > target.Length)
+ return var.Substring (target.Length + 1);
return "";
}
@@ -91,16 +91,16 @@ namespace System.Diagnostics {
*
* @param var The current MONO_TRACE variable
- * @param where The name of the output location, e.g. "Console.Out"
+ * @param target The name of the output location, e.g. "Console.Out"
*/
@@ -91,16 +91,16 @@ namespace System.Diagnostics {
{
- // actually, we permit any character to separate `where' and the prefix;
- // we just skip over where the ':' would be. This means that a space or
+ // actually, we permit any character to separate `target' and the prefix;
+ // we just skip over target the ':' would be. This means that a space or
// anything else would suffice, as long as it was only a single
// character.